Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(521)

Unified Diff: runtime/vm/class_finalizer.h

Issue 8872037: Adjust index of type parameters at finalization time (fix issue 718). (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: '' Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/lib/error.cc ('k') | runtime/vm/class_finalizer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/class_finalizer.h
===================================================================
--- runtime/vm/class_finalizer.h (revision 2282)
+++ runtime/vm/class_finalizer.h (working copy)
@@ -41,9 +41,11 @@
AbstractType* interface,
AbstractType* conflicting);
// Finalize and canonicalize type while parsing.
// Set the error message on failure (to String::null() if no error).
- static RawType* FinalizeAndCanonicalizeType(const Type& type, String* errmsg);
+ static RawAbstractType* FinalizeAndCanonicalizeType(const Class& cls,
+ const AbstractType& type,
+ String* errmsg);
// Pending classes are classes that need to be finalized.
static void AddPendingClasses(const GrowableArray<const Class*>& classes);
@@ -80,7 +82,8 @@
static void FinalizeTypeArguments(const Class& cls,
const AbstractTypeArguments& arguments);
static void ResolveType(const Class& cls, const AbstractType& type);
- static RawAbstractType* FinalizeType(const AbstractType& type);
+ static RawAbstractType* FinalizeType(const Class& cls,
+ const AbstractType& type);
static void ResolveAndFinalizeUpperBounds(const Class& cls);
static void VerifyUpperBounds(const Class& cls,
const AbstractTypeArguments& arguments);
@@ -41,9 +41,11 @@
AbstractType* interface,
AbstractType* conflicting);
- // Finalize and canonicalize type while parsing.
+ // Finalize and canonicalize type while parsing class cls.
// Set the error message on failure (to String::null() if no error).
« no previous file with comments | « runtime/lib/error.cc ('k') | runtime/vm/class_finalizer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698